DefinitionNode class

Inheritance
Mixed-in types

Constructors

DefinitionNode({required String name, Node? varType, required Node expr, required bool mut, required List<AttributeNode> attr, Loc? loc})

Properties

attr ↔ List<AttributeNode>
getter/setter pair
expr ↔ Node
Expression
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loc ↔ Loc?
The location of the source string that created this node.
getter/setter pairinherited
mut ↔ bool
getter/setter pair
name ↔ String
The name of the node.
getter/setter pairoverride-getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the node.
no setteroverride
varType ↔ Node?
NamedTypeSourceNode | FnTypeSourceNode
getter/setter pair

Methods

accept(Visitor fn) → void
Accepts a visitor.
override
isExpression() → bool
Checks if the node is an expression.
inherited
isStatement() → bool
Checks if the node is a statement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(Visitor fn) → Node
Visits the node and its child nodes.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited