IndexNode class

Inheritance

Constructors

IndexNode({required Node target, required Node index, Loc? loc})

Properties

hashCode → int
The hash code for this object.
no setterinherited
index ↔ Node
Expression
getter/setter pair
loc ↔ Loc?
The location of the source string that created this node.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Node
Expression
getter/setter pair
type → String
The type of the node.
no setteroverride

Methods

accept(Visitor fn) → void
Accepts a visitor.
override
isExpression() → bool
Checks if the node is an expression.
inherited
isStatement() → bool
Checks if the node is a statement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(Visitor fn) → Node
Visits the node and its child nodes.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited