Loc class

The location of a node.

Constructors

Loc(int start, int end)
Creates a new Loc.
Loc.fromToken(Token token)
Creates a new Loc from a Token.

Properties

end → int
Where this node ends in the script.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Where this node starts in the script.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object? other) → bool
The equality operator.
override