NativeFnValue class

A native function value.

Inheritance

Constructors

NativeFnValue(Future<Value> nativeFn(FnArgs args, Interpreter state), [OriginStatement origin = OriginStatement.none])

Properties

attributes ↔ List<Attribute>?
The value's attributes.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isMutable ↔ bool
Whether the value is mutable.
getter/setter pairinherited
nativeFn → Future<Value> Function(FnArgs args, Interpreter state)
The native function.
final
origin ↔ OriginStatement
The statement that this value was returned from.
getter/setter pairinherited
params → List<String>?
The function's parameters.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statements → List<Node>?
The statements in the function's body.
no setteroverride
type → String
The type of the value.
no setterinherited

Methods

cast<T extends Value>() → T
Cast a Value to another Value type.
inherited
clearOrigin() → void
Sets the origin statement to none
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited