FileModuleResolver class

A module resolver that loads the modules from files.

Implemented types

Constructors

FileModuleResolver(Parser parser, {List<String> paths = const [''], bool sanitizePaths = false, Encoding encoding = utf8, String? ext = '.aiscript'})
const

Properties

encoding → Encoding
The encoding of the modules. Default: utf8
final
ext → String?
The extension of the module files, including the .
final
hashCode → int
The hash code for this object.
no setterinherited
parser → Parser
The parser.
final
paths → List<String>
The module paths.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizePaths → bool
Whether to sanitize paths or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String path) → Future<ResolvedModule>
Resolves a module.
override
resolvePath(String name, String? currentPath) → Future<String?>
Resolves the full path of a module.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited